surf <- function(ord,...)
{
    UseMethod("surf")
}

jsurf <- function(ord,...)
{
    UseMethod("jsurf")
}

plotid <- function(ord,...)
{
    UseMethod("plotid")
}

specid <- function(ord,...)
{
    UseMethod("specid")
}

hilight <- function(ord, ...)
{
    UseMethod("hilight")
}

chullord <- function(ord, ...)
{
    UseMethod("chullord")
}
